require 'uu/os/rest/dto'
require 'uu/os/uesuri'
require 'uu/os/env/process/process_message'

module UU
  module OS
    module Env
      module Process

        # Parameters for initialization of process.
        class ProcessRun < UU::OS::REST::DTO

          # URI of main entity.
          # @param [String, UU::OS::UESURI]
          # @return [UU::OS::UESURI]
          attr_accessor :main_entity_uri

          # URI of parent process.
          # @param [String, UU::OS::UESURI]
          # @return [UU::OS::UESURI]
          attr_accessor :parent_process_uri

          # Process initialization message.
          # @param [String, UU::OS::Env::Process::ProcessMessage]
          # @return [UU::OS::Env::Process::ProcessMessage]
          attr_accessor :message

          # Total process steps.
          # @param [Numeric]
          # @return [Numeric]
          attr_accessor :total_steps

          def main_entity_uri
            attributes[:mainEntityUri]
          end

          def main_entity_uri=(val)
            if val
              attributes[:mainEntityUri] = UU::OS::UESURI.new(val)
            else
              attributes[:mainEntityUri] = nil
            end
          end

          def parent_process_uri
            attributes[:parentProcessUri]
          end

          def parent_process_uri=(val)
            if val
              attributes[:parentProcessUri] = UU::OS::UESURI.new(val)
            else
              attributes[:parentProcessUri] = nil
            end
          end

          def message
            attributes[:message]
          end

          def message=(val)
            if val
              attributes[:message] = UU::OS::Env::Process::ProcessMessage.new(val)
            else
              attributes[:message] = nil
            end
          end
          
          def total_steps
            attributes[:totalSteps]
          end
          
          def total_steps=(val)
            attributes[:totalSteps]
          end

        end

      end
    end
  end
end
